# -*- coding: utf-8 -*-

from pydiploy.require import (circus, databases, django, git, nginx, python,
                              releases_manager, system, simple, bottle)
